@@ -1,4 +1,4 @@
-/* @(#) $Header: /cvsroot/hams/ax25-apps/listen/arpdump.c,v 1.1.1.1 2000/05/03 02:43:52 csmall Exp $ */
+/* @(#) $Header: /cvsroot/ax25/ax25-apps/listen/arpdump.c,v 1.2 2001/09/12 13:18:43 terry Exp $ */
 
 /* ARP packet tracing routines
  * Copyright 1991 Phil Karn, KA9Q
@@ -31,20 +31,18 @@ void arp_dump(unsigned char *data, int length)
 
 	lprintf(T_PROTOCOL, "ARP: ");
 	lprintf(T_IPHDR, "len %d", length);
-	if (length < 16)
-	{
+	if (length < 16) {
 		lprintf(T_ERROR, " bad packet\n");
 		return;
 	}
 
-	hardware  = get16(data + 0);
-	protocol  = get16(data + 2);
-	hwlen     = data[4];
-	pralen    = data[5];
+	hardware = get16(data + 0);
+	protocol = get16(data + 2);
+	hwlen = data[4];
+	pralen = data[5];
 	operation = get16(data + 6);
-	
-	if (hardware != ARP_AX25)
-	{
+
+	if (hardware != ARP_AX25) {
 		lprintf(T_IPHDR, " non-AX25 ARP packet\n");
 		return;
 	}
@@ -57,18 +55,14 @@ void arp_dump(unsigned char *data, int length)
 	if (hwlen != AXALEN)
 		lprintf(T_IPHDR, " hwlen %d", hwlen);
 
-	if (protocol == PID_IP)
-	{
+	if (protocol == PID_IP) {
 		lprintf(T_IPHDR, " prot IP");
 		is_ip = 1;
-	}
-	else
-	{
+	} else {
 		lprintf(T_IPHDR, " prot 0x%x prlen %d", protocol, pralen);
 	}
 
-	switch (operation)
-	{
+	switch (operation) {
 	case ARP_REQUEST:
 		lprintf(T_IPHDR, " op REQUEST");
 		break;
@@ -85,21 +79,23 @@ void arp_dump(unsigned char *data, int length)
 		lprintf(T_IPHDR, " op %d", operation);
 		break;
 	}
-	
-	shwaddr   = data + 8;
+
+	shwaddr = data + 8;
 	sprotaddr = shwaddr + hwlen;
-	
-	thwaddr   = sprotaddr + pralen;
-	tprotaddr = thwaddr + hwlen; 
-	
+
+	thwaddr = sprotaddr + pralen;
+	tprotaddr = thwaddr + hwlen;
+
 	lprintf(T_IPHDR, "\nsender");
-	if (is_ip) lprintf(T_ADDR, " IPaddr %d.%d.%d.%d",
+	if (is_ip)
+		lprintf(T_ADDR, " IPaddr %d.%d.%d.%d",
 			sprotaddr[0], sprotaddr[1],
 			sprotaddr[2], sprotaddr[3]);
 	lprintf(T_IPHDR, " hwaddr %s\n", pax25(tmp, shwaddr));
 
-	lprintf(T_IPHDR,"target");
-	if (is_ip) lprintf(T_ADDR, " IPaddr %d.%d.%d.%d",
+	lprintf(T_IPHDR, "target");
+	if (is_ip)
+		lprintf(T_ADDR, " IPaddr %d.%d.%d.%d",
 			tprotaddr[0], tprotaddr[1],
 			tprotaddr[2], tprotaddr[3]);
 	if (*thwaddr != 0)
